;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Nome do arquivo: .emacs    
;; Ultima atualizacao: Mon May 21 11:32:39 BRST 2001
;; Arlan Lucas de Souza <arlanlucas@bol.com.br>
;;
;; Dicas:
;; ------
;; A data acima foi impressa com o comando "C-u M-! date",
;; que executou um comando shell, no caso o comando "date" do
;; do Linux/Unix, direcionando sua saida para o buffer atual. 
;; -----
;; Uma das muitas alternativas para se identificar pares de
;; parenteses sao os comandos "C-M-f", para parentese a frente,
;; e "C-M-b, para parentese anterior.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;-----------------------------------------------------------
;                     Teclas de atalho
;-----------------------------------------------------------
(global-set-key "\C-x\C-b" 'buffer-menu)         ; C-x C-b
(global-set-key [(control tab)] 'bury-buffer)	 ; C-tab
(global-set-key "\M-o" 'other-window)            ; M-o

;-----------------------------------------------------------
;                   Configuracoes diversas             
;-----------------------------------------------------------
; Defina o modo texto com quebra de linha como o modo padrao.
(setq default-major-mode 'text-mode)
(add-hook 'text-mode-hook 'turn-on-auto-fill)

; Nao alterne o cursor sobre pares de parenteses.
(setq blink-matching-paren nil)

; Nao realize auto-salvamento dos arquivos.
(setq auto-save-default nil)

; Aceite 'y' ou 'n' em vez de 'yes' ou 'no' como resposta a perguntas.
(fset 'yes-or-no-p 'y-or-n-p)

; Mostre o numero da coluna (posicao do cursor).
(column-number-mode t)

; Nao mostre a barra de menu.
(menu-bar-mode -1)

; Role a tela linha por linha e nao aos montes
(progn (setq scroll-step 1)
       (setq scroll-preserve-screen-position t)
       (setq scroll-conservatively 9999))

; Permita o arraste da barra de rolagem com o botao esquerdo do mouse.
(global-set-key [vertical-scroll-bar down-mouse-1] 'scroll-bar-drag)

; Nao adicione novas linhas ao chegar ao final do arquivo.
(setq next-line-add-newlines nil)

; Destaque a sintaxe.
(global-font-lock-mode t)

; Permita restringir atuacao de um comando a uma regiao sem confirmacao.
(put 'narrow-to-region 'disabled nil)

; Defina aparencia das janelas, frames, cursor, etc.
(setq default-frame-alist 
   '((cursor-color . "red") 
     (cursor-type . box)     
     (width . 79) (height . 31)
     (background-color . "LightSteelBlue")
     (foreground-color . "black")))

; Desligue o aviso sonoro.
(setq visible-bell t)

;-----------------------------------------------------------
;                   Corretor ortografico                    
;-----------------------------------------------------------
(global-set-key "\C-cb" 'ispell-buffer)
(global-set-key "\C-cr" 'ispell-region)
(global-set-key "\C-cw" 'ispell-word)

; Habilita o dicionario portugues brasileiro
(setq ispell-local-dictionary-alist '((
         "br" "[A-Za-z]" 
         "[^A-Za-z]" "[---]" 
         nil ("-B" "-d" "br") "~tex" iso-latin-1)))

; Torne o dicionario brasileiro o padrao
(setq ispell-dictionary "br")

;-----------------------------------------------------------
;                      Arquivos de backup                    
;-----------------------------------------------------------
; Guarde arquivos de backup em ~/.backups/
(defun make-backup-file-name (file-name)                     
  "Create the non-numeric backup file name for `file-name'." 
  (require 'dired)
  (if (file-exists-p "~/.backups") 
      (concat (expand-file-name "~/.backups/")
      (dired-replace-in-string "/" "|" file-name))
      (concat file-name "~")))
;---------------------- final de .emacs --------------------